@@ -146,10 +146,11 @@ class Controller:
             
             if UP_TO_DATE:
                 self.log(f"task [red]{task.uid}[/red] is up to date, skipping it.")
-                return                                                     
+                return(False)
 
         self.log(f"adding [red]{task.uid}[/red]")
         self.log(" - cmd: {}".format( " ".join(task.get_command() ) ))
+        return(True)
 
     def complete_task(self, task):
         # load the results if any
